@@ -1,5 +1,5 @@
 import matplotlib.pyplot as plt
-import matplotlib_iterm2
+import oldmatplotlib
 import time
 import random
 
